@@ -598,9 +598,9 @@ class Device(aio.DatagramProtocol):
         else:
             mycallb = lambda x, y: mypartial(y)
         if value in on and not rapid:
-            response = self.req_with_ack(SetPower, {"power_level": 65535}, mycallb)
+            response = self.req_with_ack(SetPower, {"power_level": 65535}, callb=mycallb)
         elif value in off and not rapid:
-            response = self.req_with_ack(SetPower, {"power_level": 0}, mycallb)
+            response = self.req_with_ack(SetPower, {"power_level": 0}, callb=mycallb)
         elif value in on and rapid:
             response = self.fire_and_forget(SetPower, {"power_level": 65535})
             self.power_level = 65535
@@ -635,7 +635,7 @@ class Device(aio.DatagramProtocol):
                 mycallb = lambda x, y: (mypartial(y), callb(x, y))
             else:
                 mycallb = lambda x, y: mypartial(y)
-            response = self.req_with_resp(GetWifiFirmware, StateWifiFirmware, mycallb)
+            response = self.req_with_resp(GetWifiFirmware, StateWifiFirmware, callb=mycallb)
         return (self.wifi_firmware_version, self.wifi_firmware_build_timestamp)
 
     def resp_set_wififirmware(self, resp):
@@ -682,7 +682,8 @@ class Device(aio.DatagramProtocol):
                 mycallb = lambda x, y: (mypartial(y), callb(x, y))
             else:
                 mycallb = lambda x, y: mypartial(y)
-            response = self.req_with_resp(GetHostFirmware, StateHostFirmware, mycallb)
+            response = self.req_with_resp(GetHostFirmware, StateHostFirmware, callb=mycallb)
+
         return (self.host_firmware_version, self.host_firmware_build_timestamp)
 
     def resp_set_hostfirmware(self, resp):
